@@ -16,7 +16,7 @@ class ExecOnPodError(Exception):
         self.err = err
 
     def __str__(self):
-        return f"Command execution failure: {self.cmd} RC: {self.rc}, OUT: {self.out}, ERR: {self.err}"
+        return "fCommand execution failure: " f"{self.cmd}, RC: {self.rc}, OUT: {self.out}, ERR: {self.err}"
 
 
 class Pod(NamespacedResource):
